@@ -64,7 +64,7 @@ require DynaLoader;
 }
 $EXPORT_TAGS{ALL}= \@EXPORT_OK;
 
-$VERSION = '0.12';
+$VERSION = '0.13';
 
 sub AUTOLOAD {
     my $constname;
@@ -418,7 +418,7 @@ The C<user> whose information you want.
 
 =item C<level> - Scalar Int
 
-One of: 0, 1, 2, 3, 10, 11 and 20. See L<USER INFO LEVELS>.
+One of: 0, 1, 2, 3, 4, 10, 11, 20, 21, 22 and 23. See L<USER INFO LEVELS>.
 
 =item C<hash> - Hash Reference
 
@@ -563,8 +563,8 @@ The C<server> on which to add the group.
 
 =item C<level> - Scalar String
 
-The C<level> of information contained in C<hash>. This can be one of 0, 1
-or 2. See L<GROUP INFO LEVELS>.
+The C<level> of information contained in C<hash>. This can be one of 0, 1, 2
+or 3. See L<GROUP INFO LEVELS>.
 
 =item C<hash> - Hash Reference
 
@@ -1051,6 +1051,16 @@ acctExpires, maxStorage, unitsPerWeek, logonHours, badPwCount, numLogons,
 logonServer, countryCode, codePage, userId, primaryGroupId, profile,
 homeDirDrive, passwordExpired
 
+=item Level 4
+
+name, password, passwordAge, priv, homeDir, comment, flags, scriptPath,
+authFlags, fullName, usrComment, parms, workstations, lastLogon, lastLogoff,
+acctExpires, maxStorage, unitsPerWeek, logonHours, badPwCount, numLogons,
+logonServer, countryCode, codePage, userSid, primaryGroupId, profile,
+homeDirDrive, passwordExpired
+
+B<Note:> This level is only supported on Windows Server 2003 and later.
+
 =item Level 10
 
 name, comment, usrComment, fullName
@@ -1067,11 +1077,20 @@ name, fullName, comment, flags, userId
 
 =item Level 21
 
-B<Not available in this implementation>
+password (array)
 
 =item Level 22
 
-B<Not available in this implementation>
+name, fullName, password (array), passwordAge, priv, homeDir, comment, flags,
+scriptPath, usrComment, workstations, lastLogon, lastLogoff, maxStorage,
+unitsPerWeek, logonHours, numLogons, logonServer, countryCode, codePage,
+parms
+
+=item Level 23
+
+userSid, flags, comment, fullName, name
+
+B<Note:> This level is only supported on Windows Server 2003 and later.
 
 =item Level 1003
 
@@ -1275,6 +1294,11 @@ information.
 The password to be set. The password is never returned in a C<UserGet()>
 operation.
 
+=item C<password (array)> - 16 bytes array
+
+The password to be set. Specifies a one-way encrypted LAN Manager
+2.x-compatible password.
+
 =item C<passwordAge> - Scalar Int (UTC)
 
 The current age of the password (stored as the number of seconds since
@@ -1319,18 +1343,25 @@ Its use is beyond the scope of this package.
 
 The user comment field (contrasted with the comment field ;-).
 
-=item C<workstations> - Scalar String
-
-A comma-separated string containing upto 8 workstation that the named
-user can login to.  Setting a value for this key will then allow the
-named user to login to only those computers named.
-
 =item C<userId> - Scalar Int
 
 The user id associated with this user This value is generated by the
 system and cannot be set or changed using the C<UserAdd()> or
 C<UserSetInfo()> calls.
 
+=item C<userSid> - Scalar String
+
+Secure Identifier that uniquely identifies the user. A SID has the format
+I<S-R-I-S...>. In this notation, the literal character "S" identifies the
+series of digits as a SID, I<R> is the revision level, I<I> is the
+identifier-authority value, and I<S...> is one or more subauthority values.
+
+=item C<workstations> - Scalar String
+
+A comma-separated string containing upto 8 workstation that the named
+user can login to.  Setting a value for this key will then allow the
+named user to login to only those computers named.
+
 =back
 
 
@@ -1615,6 +1646,10 @@ name, comment.
 
 name, comment, groupId, attributes.
 
+=item C<Level 3>
+
+name, comment, groupSid, attributes.
+
 =item C<Level 1002>
 
 comment.
@@ -1644,6 +1679,13 @@ can be set via a GroupSetInfo call.
 
 The groups Id.
 
+=item C<groupSid>
+
+Secure Identifier that uniquely identifies the group. A SID has the format
+I<S-R-I-S...>. In this notation, the literal character "S" identifies the
+series of digits as a SID, I<R> is the revision level, I<I> is the
+identifier-authority value, and I<S...> is one or more subauthority values.
+
 =item C<name> - Scalar String
 
 The groups name.
